@@ -1,5 +1,5 @@
 package Image::Info::XPM;
-$VERSION = '1.07';
+$VERSION = '1.09';
 use strict;
 use Image::Xpm 1.09;
 
@@ -12,7 +12,7 @@ sub process_file{
     };
 
     my $i = Image::Xpm->new(-width => 0, -height => 0);
-    # loading the file as a seperate step avoids a "-r" test, this would
+    # loading the file as a separate step avoids a "-r" test, this would
     # file with in-memory strings (aka fake files)
     $i->load($source);
 
@@ -107,7 +107,7 @@ sub _get_rgb_txt{
 	'/X11/R5/lib/X11/rgb.txt',
 	'/X11/R4/lib/rgb/rgb.txt',
 	'/usr/openwin/lib/X11/rgb.txt',
-	'/usr/share/X11/rgb.txt', # This is the Debian location
+	'/usr/share/X11/rgb.txt', # This is the Debian and RH5 location
 	'/usr/X11/share/X11/rgb.txt', # seen on a Mac OS X 10.5.1 system
 	'/usr/X11R6/share/X11/rgb.txt', # seen on a OpenBSD 4.2 system
 	'/etc/X11R6/rgb.txt',
